==> 3.5.12-core.tar: kdevelop/parts/documentation/plugins/pdb/docpdbplugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Mathieu Chouinard                               *
 *   mathieu.chouinard@kdemail.net	                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#include "docpdbplugin.h"

#include <kurl.h>
#include <kaboutdata.h>
#include <kconfig.h>
#include <klocale.h>
#include <klistview.h>

#include <kdevgenericfactory.h>

static const KAboutData data("docpdbplugin", I18N_NOOP("PalmDoc documentation plugin"), "1.0");
typedef KDevGenericFactory<DocPDBPlugin> DocPDBPluginFactory;
K_EXPORT_COMPONENT_FACTORY( libdocpdbplugin, DocPDBPluginFactory(&data) )

DocPDBPlugin::DocPDBPlugin(TQObject* parent, const char* name, const TQStringList args)
    :DocumentationPlugin(DocPDBPluginFactory::instance()->config(), parent, name)
{
    setCapabilities(CustomDocumentationTitles | ProjectUserManual);
    autoSetup();
}

DocPDBPlugin::~DocPDBPlugin()
{
}

bool DocPDBPlugin::needRefreshIndex(DocumentationCatalogItem* item)
{
    return false;
}

TQString DocPDBPlugin::pluginName() const
{
    return i18n("PalmDoc Documentation Collection");
}

DocumentationCatalogItem* DocPDBPlugin::createCatalog(KListView* contents, const TQString& title, const TQString& url)
{
    DocumentationCatalogItem *item = new DocumentationCatalogItem(this, contents, title);
    item->setURL(KURL(url));
    return item;
}

QPair<KFile::Mode, TQString> DocPDBPlugin::catalogLocatorProps()
{
    return QPair<KFile::Mode, TQString>(KFile::File, "all/allfiles");
}

TQString DocPDBPlugin::catalogTitle(const TQString& /*url*/)
{
    return TQString::null;
}

TQStringList DocPDBPlugin::fullTextSearchLocations()
{
    return TQStringList();
}


void DocPDBPlugin::autoSetupPlugin()
{
    return;
}

void DocPDBPlugin::createIndex(IndexBox* /*index*/, DocumentationCatalogItem* /*item*/)
{
    return;
}

void DocPDBPlugin::createTOC(DocumentationCatalogItem* /*item*/)
{
    return;
}

void DocPDBPlugin::setCatalogURL(DocumentationCatalogItem* /*item*/)
{
    return;
}

ProjectDocumentationPlugin *DocPDBPlugin::projectDocumentationPlugin(ProjectDocType type)
{
    if (type == UserManual)
        return new ProjectDocumentationPlugin(this, type);
    return DocumentationPlugin::projectDocumentationPlugin(type);
}

==> 3.5.13-core.tar: kdevelop/parts/documentation/plugins/pdb/docpdbplugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2004 by Mathieu Chouinard                               *
 *   mathieu.chouinard@kdemail.net	                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#include "docpdbplugin.h"

#include <kurl.h>
#include <kaboutdata.h>
#include <kconfig.h>
#include <klocale.h>
#include <klistview.h>

#include <kdevgenericfactory.h>

static const KAboutData data("docpdbplugin", I18N_NOOP("PalmDoc documentation plugin"), "1.0");
typedef KDevGenericFactory<DocPDBPlugin> DocPDBPluginFactory;
K_EXPORT_COMPONENT_FACTORY( libdocpdbplugin, DocPDBPluginFactory(&data) )

DocPDBPlugin::DocPDBPlugin(TQObject* parent, const char* name, const TQStringList args)
    :DocumentationPlugin(DocPDBPluginFactory::instance()->config(), parent, name)
{
    setCapabilities(CustomDocumentationTitles | ProjectUserManual);
    autoSetup();
}

DocPDBPlugin::~DocPDBPlugin()
{
}

bool DocPDBPlugin::needRefreshIndex(DocumentationCatalogItem* item)
{
    return false;
}

TQString DocPDBPlugin::pluginName() const
{
    return i18n("PalmDoc Documentation Collection");
}

DocumentationCatalogItem* DocPDBPlugin::createCatalog(KListView* contents, const TQString& title, const TQString& url)
{
    DocumentationCatalogItem *item = new DocumentationCatalogItem(this, contents, title);
    item->setURL(KURL(url));
    return item;
}

TQPair<KFile::Mode, TQString> DocPDBPlugin::catalogLocatorProps()
{
    return TQPair<KFile::Mode, TQString>(KFile::File, "all/allfiles");
}

TQString DocPDBPlugin::catalogTitle(const TQString& /*url*/)
{
    return TQString();
}

TQStringList DocPDBPlugin::fullTextSearchLocations()
{
    return TQStringList();
}


void DocPDBPlugin::autoSetupPlugin()
{
    return;
}

void DocPDBPlugin::createIndex(IndexBox* /*index*/, DocumentationCatalogItem* /*item*/)
{
    return;
}

void DocPDBPlugin::createTOC(DocumentationCatalogItem* /*item*/)
{
    return;
}

void DocPDBPlugin::setCatalogURL(DocumentationCatalogItem* /*item*/)
{
    return;
}

ProjectDocumentationPlugin *DocPDBPlugin::projectDocumentationPlugin(ProjectDocType type)
{
    if (type == UserManual)
        return new ProjectDocumentationPlugin(this, type);
    return DocumentationPlugin::projectDocumentationPlugin(type);
}
